@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Value 2.151;
+package Config::Model::Value 2.152;
 
 use v5.20;
 
@@ -120,10 +120,14 @@ has error_list => (
     } );
 
 sub error_msg  ($self) {
-    my @add;
-    push @add, $self->compute_obj->compute_info if $self->compute_obj;
-    push @add, $self->{_migrate_from}->compute_info if $self->{_migrate_from};
-    return join("\n", $self->all_errors, @add);
+    my $msg = '';
+    if ($self->has_error) {
+        my @add;
+        push @add, $self->compute_obj->compute_info if $self->compute_obj;
+        push @add, $self->{_migrate_from}->compute_info if $self->{_migrate_from};
+        $msg = join("\n", $self->all_errors, @add);
+    }
+    return $msg;
 }
 
 has warning_list => (
@@ -2000,7 +2004,7 @@ Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 2.151
+version 2.152
 
 =head1 SYNOPSIS
 
